@@ -58,6 +58,9 @@ general_fit <- function(X, y, groups, model, path_fcn, var_screen_fcn, grp_scree
   if (type == "logistic" & intercept == TRUE){
     warning("logistic regression with intercept has a bug. See sgs GitHub page for more details")
   }
+  if (!check_group_vector(groups)){ # check if group indexes ordered correctly
+    warning("group indices are not set from 1, contain gaps, or are not ordered, which can lead to a bug during fitting. See GitHub page for more details.")
+  } 
 
   # identify fit type
   if (any(lambda == "path") | length(lambda) > 1){
@@ -422,8 +425,8 @@ general_fit_cv = function(X, y, groups, model, path_fcn, type, lambda, path_leng
   output_model$pen_gslope = lambda_model$pen_gslope
   output_model$lambda = lambda_model$lambda[best_lambda_id]
   output_model$type = lambda_model$type
-  output_model$standardise = lambda_model$standardise
   output_model$intercept = lambda_model$intercept
+  output_model$standardise = lambda_model$standardise
   output_model$num_it = lambda_model$num_it[best_lambda_id]
   output_model$success = lambda_model$success[best_lambda_id]
   output_model$certificate = lambda_model$certificate[best_lambda_id]
